<?php
    /**
     * @author Mat <mat_sf@users.sourceforge.net>
     */
    class HitsGraph {

        private $plot;
        private $dayStats;
        private $weekStats;
        private $monthStats;
        private $yearStats;

        function __construct() {
            $this->plot = new PHPlot(700, 1000);
            $this->plot->SetImageBorderType('plain');

            $this->plot->SetPlotType('bars');
            $this->plot->SetDataType('text-data');
            if (PHPlotConfiguration::$useTTF) {
                $this->plot->SetDefaultTTFont(PHPlotConfiguration::getPathToTTF());

                $this->plot->SetFont("x_label", "", PHPlotConfiguration::$xLabelTTF);
                $this->plot->SetFont("y_label", "", PHPlotConfiguration::$yLabelTTF);
                $this->plot->SetFont("x_title", "", PHPlotConfiguration::$xTitleTTF);
                $this->plot->SetFont("y_title", "", PHPlotConfiguration::$yTitleTTF);
            } else {
                $this->plot->SetFont("x_label", PHPlotConfiguration::$xLabel, PHPlotConfiguration::$xLabel);
                $this->plot->SetFont("y_label", PHPlotConfiguration::$yLabel, PHPlotConfiguration::$yLabel);
                $this->plot->SetFont("x_title", PHPlotConfiguration::$xTitle, PHPlotConfiguration::$xTitle);
                $this->plot->SetFont("y_title", PHPlotConfiguration::$yTitle, PHPlotConfiguration::$yTitle);
            }

            # Turn on Y data labels:
            $this->plot->SetYDataLabelPos('plotin');

            # With Y data labels, we don't need Y ticks or their labels, so turn them off.
            $this->plot->SetYTickLabelPos('none');
            $this->plot->SetYTickPos('none');

            # Turn off X tick labels and ticks because they don't apply here:
            $this->plot->SetXTickLabelPos('none');
            $this->plot->SetXTickPos('none');

            # Disable auto-output:
            $this->plot->SetPrintImage(0);

        }

        public function getStats() {
            $this->prepareStats();
            
            $this->dayStatsGraph();
            $this->weekStatsGraph();
            $this->monthStatsGraph();
            $this->yearStatsGraph();

            # Output the image now:
            $this->plot->PrintImage();


            return true;
        }

        public function prepareStats() {
            $hitsFacade = new HitsFacade();
            $data = $hitsFacade->prepare();

            $this->dayStats = $this->getDayGraphData($data);
            $this->weekStats = $this->getWeekGraphData($data);
            $this->monthStats = $this->getMonthGraphData($data);
            $this->yearStats = $this->getYearGraphData($data);
        }

        public function dayStatsGraph() {
            global $fp_config, $lang;

            $this->plot->SetPlotAreaPixels(20, 40, 680, 240);
            $this->plot->SetPlotAreaWorld(null,null,null,null);

            //$plot->SetIsInline(true);
            $this->plot->SetDataValues($this->dayStats);

            # Main plot title:
            $this->plot->SetXTitle($lang['admin']['plugin']['fpstats']['dayStats']);

            # Make a legend for the 3 data sets plotted:
            $this->plot->SetLegend(array($lang['admin']['plugin']['fpstats']['allHits'],
                                            $lang['admin']['plugin']['fpstats']['uniqueHits'],
                                            $lang['admin']['plugin']['fpstats']['crawlers']));

            $this->plot->DrawGraph();

            return true;
        }
        
        public function weekStatsGraph() {
            global $fp_config, $lang;

            $this->plot->SetPlotAreaPixels(20, 300, 680, 480);
            $this->plot->SetPlotAreaWorld(null,null,null,null);

            //$plot->SetIsInline(true);
            $this->plot->SetDataValues($this->weekStats);

            # Main plot title:
            $this->plot->SetXTitle($lang['admin']['plugin']['fpstats']['weekStats']);

            # Make a legend for the 3 data sets plotted:
            $this->plot->SetLegend(array($lang['admin']['plugin']['fpstats']['allHits'],
                                            $lang['admin']['plugin']['fpstats']['uniqueHits'],
                                            $lang['admin']['plugin']['fpstats']['crawlers']));

            $this->plot->DrawGraph();

            return true;
        }

        public function monthStatsGraph() {
            global $fp_config, $lang;

            $this->plot->SetPlotAreaPixels(20, 540, 680, 720);
            $this->plot->SetPlotAreaWorld(null,null,null,null);
            //$plot->SetIsInline(true);
            $this->plot->SetDataValues($this->monthStats);

            # Main plot title:
            $this->plot->SetXTitle($lang['admin']['plugin']['fpstats']['monthStats']);

            # Make a legend for the 3 data sets plotted:
            $this->plot->SetLegend(array($lang['admin']['plugin']['fpstats']['allHits'],
                                            $lang['admin']['plugin']['fpstats']['uniqueHits'],
                                            $lang['admin']['plugin']['fpstats']['crawlers']));

            $this->plot->DrawGraph();

            return true;
        }

        public function yearStatsGraph() {
            global $fp_config, $lang;

            $this->plot->SetPlotAreaPixels(20, 780, 680, 960);
            $this->plot->SetPlotAreaWorld(null,null,null,null);
            
            //$plot->SetIsInline(true);
            $this->plot->SetDataValues($this->yearStats);

            # Main plot title:
            $this->plot->SetXTitle($lang['admin']['plugin']['fpstats']['yearStats']);

            # Make a legend for the 3 data sets plotted:
            $this->plot->SetLegend(array($lang['admin']['plugin']['fpstats']['allHits'],
                                            $lang['admin']['plugin']['fpstats']['uniqueHits'],
                                            $lang['admin']['plugin']['fpstats']['crawlers']));

            $this->plot->DrawGraph();

            return true;
        }



        public function getYearGraphData($summary) {
            $yearStats=null;
            foreach($summary as $key => $value) {
                $year = date("Y",$key);
                $found=false;

                if (is_array($yearStats)) {
                    for($i=0; $i< sizeof($yearStats); $i++) {
                        if ($yearStats[$i][0]==$year) {
                            $yearStats[$i][1] = $yearStats[$i][1] + $value->getAllHits();
                            $yearStats[$i][2] = $yearStats[$i][2] + $value->getUniqueHits();
                            $yearStats[$i][3] = $yearStats[$i][3] + $value->getCrawlers();
                            $found=true;
                            break;
                        }
                    }
                }

                if (!$found) {
                    $ystmp[0] = $year;
                    $ystmp[1] = $value->getAllHits();
                    $ystmp[2] = $value->getUniqueHits();
                    $ystmp[3] = $value->getCrawlers();
                    $yearStats[] = $ystmp;
                }
            }

            return $yearStats;
        }

        public function getMonthGraphData($summary) {
            $lastYear = strtotime("-12 months");
            $monthStats=null;
            foreach($summary as $key => $value) {
                if ($key < $lastYear) {
                    continue;
                }
                $month = date("F",$key);
                $found=false;

                if (is_array($monthStats)) {
                    for($i=0; $i< sizeof($monthStats); $i++) {
                        if ($monthStats[$i][0]==$month) {
                            $monthStats[$i][1] = $monthStats[$i][1] + $value->getAllHits();
                            $monthStats[$i][2] = $monthStats[$i][2] + $value->getUniqueHits();
                            $monthStats[$i][3] = $monthStats[$i][3] + $value->getCrawlers();
                            $found=true;
                            break;
                        }
                    }
                }

                if (!$found) {
                    $mstmp[0] = $month;
                    $mstmp[1] = $value->getAllHits();
                    $mstmp[2] = $value->getUniqueHits();
                    $mstmp[3] = $value->getCrawlers();
                    $monthStats[] = $mstmp;
                }
            }

            return $monthStats;
        }

        public function getDayGraphData($summary) {
            $lastMonth = strtotime("-17 days");

            $dayStats=null;

            foreach($summary as $key => $value) {
                if ($key < $lastMonth) {
                    continue;
                }
                $day = date("j.n.",$key);
                $found=false;

                if (is_array($dayStats)) {
                    for($i=0; $i< sizeof($dayStats); $i++) {
                        if ($dayStats[$i][0]==$day) {
                            $dayStats[$i][1] = $dayStats[$i][1] + $value->getAllHits();
                            $dayStats[$i][2] = $dayStats[$i][2] + $value->getUniqueHits();
                            $dayStats[$i][3] = $dayStats[$i][3] + $value->getCrawlers();
                            $found=true;
                            break;
                        }
                    }
                }

                if (!$found) {
                    $dstmp[0] = $day;
                    $dstmp[1] = $value->getAllHits();
                    $dstmp[2] = $value->getUniqueHits();
                    $dstmp[3] = $value->getCrawlers();
                    $dayStats[] = $dstmp;
                }
            }

            return $dayStats;
        }

        public function getWeekGraphData($summary) {
            $lastMonth = strtotime("-17 weeks");

            $weekStats=null;
            foreach($summary as $key => $value) {
                if ($key < $lastMonth) {
                    continue;
                }
                $week = date("W",$key);
                $found=false;

                if (is_array($weekStats)) {
                    for($i=0; $i< sizeof($weekStats); $i++) {
                        if ($weekStats[$i][0]==$week) {
                            $weekStats[$i][1] = $weekStats[$i][1] + $value->getAllHits();
                            $weektats[$i][2] = $weekStats[$i][2] + $value->getUniqueHits();
                            $weekStats[$i][3] = $weekStats[$i][3] + $value->getCrawlers();
                            $found=true;
                            break;
                        }
                    }
                }

                if (!$found) {
                    $wstmp[0] = $week;
                    $wstmp[1] = $value->getAllHits();
                    $wstmp[2] = $value->getUniqueHits();
                    $wstmp[3] = $value->getCrawlers();
                    $weekStats[] = $wstmp;
                }
            }

            return $weekStats;
        }
    }

?>
