<?php
    /**
     * @author Mat <mat_sf@users.sourceforge.net>
     */
    class SWGraph {

        private $plot;
        private $browserStats;
        private $osStats;

        function __construct() {
            global $fp_config, $lang;
            $this->plot = new PHPlot(700, 700);
            $this->plot->SetImageBorderType('plain');

            $this->plot->SetPlotType('pie');
            $this->plot->SetDataType('text-data-single');

            if (PHPlotConfiguration::$useTTF) {
                $this->plot->SetDefaultTTFont(PHPlotConfiguration::getPathToTTF());

                $this->plot->SetFont("x_label", "", PHPlotConfiguration::$xLabelTTF);
                $this->plot->SetFont("y_label", "", PHPlotConfiguration::$yLabelTTF);
                $this->plot->SetFont("x_title", "", PHPlotConfiguration::$xTitleTTF);
                $this->plot->SetFont("y_title", "", PHPlotConfiguration::$yTitleTTF);
            }

            $this->plot->SetDataColors(array('red', 'green', 'blue', 'yellow', 'cyan',
                        'magenta', 'brown', 'lavender', 'pink',
                        'gray', 'orange'));

            $this->plot->SetShading(1);

            $title = $lang['admin']['plugin']['fpstats']['browsersAndOses'] ."\n".
                    $lang['admin']['plugin']['fpstats']['since'] . " " . date("01.m.Y");
            $this->plot->setTitle($title);
            
            # Disable auto-output:
            $this->plot->SetPrintImage(0);

        }

        public function getStats() {
            $swFacade = new SWFacade();
            $data = $swFacade->prepare();

            $this->browserStats = $this->getBrowserGraphData($data);
            $this->browserStatsGraph();

            $this->osStats = $this->getOSGraphData($data);
            $this->osStatsGraph();

            # Output the image now:
            $this->plot->PrintImage();


            return true;
        }

        public function getBrowserGraphData($summary) {
            $lastMonth = strtotime(date("1.m.Y"));

            $swRecord = $summary[$lastMonth];
            $array = null;
            foreach ($swRecord->getBrowserArray() as $key => $value) {
                $record = null;
                $record[] = $key;
                $record[] = $value;
                $array[] = $record;
            }

            $array = Uarsorter::sortArrayOfArrays($array);

            return $array;
        }

        public function browserStatsGraph() {
            global $fp_config, $lang;

            $this->plot->SetPlotAreaPixels(-200, 0, 700, 350);

            //$plot->SetIsInline(true);
            $this->plot->SetDataValues($this->browserStats);

            # Build a legend from our data array.
            # Each call to SetLegend makes one line as "label: value".
            foreach ($this->browserStats as $row)
              $this->plot->SetLegend(implode(': ', $row));

            $this->plot->DrawGraph();

            return true;
        }

        public function getOSGraphData($summary) {
            $lastMonth = strtotime(date("1.m.Y"));

            $swRecord = $summary[$lastMonth];
            $array = null;
            foreach ($swRecord->getOSArray() as $key => $value) {
                $record = null;
                $record[] = $key;
                $record[] = $value;
                $array[] = $record;
            }

            $array = Uarsorter::sortArrayOfArrays($array);
            
            return $array;
        }

        public function osStatsGraph() {
            global $fp_config, $lang;
            $this->plot->SetPlotAreaPixels(-200, 350, 700, 700);

            //$plot->SetIsInline(true);
            $this->plot->SetDataValues($this->osStats);

            $this->plot->legend = null;
            # Build a legend from our data array.
            # Each call to SetLegend makes one line as "label: value".
            foreach ($this->osStats as $row)
              $this->plot->SetLegend(implode(': ', $row));

            $this->plot->DrawGraph();

            return true;
        }
    }

?>
